==> tencentcloud-sdk-java-3.1.1130-sources.jar: com/tencentcloudapi/cdb/v20170320/models/SubmitInstanceUpgradeCheckJobRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cdb.v20170320.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SubmitInstanceUpgradeCheckJobRequest extends AbstractModel {

    /**
    * 实例D
    */
    @SerializedName("InstanceId")
    @Expose
    private String InstanceId;

    /**
    * 目标数据库版本
    */
    @SerializedName("DstMysqlVersion")
    @Expose
    private String DstMysqlVersion;

    /**
     * Get 实例D 
     * @return InstanceId 实例D
     */
    public String getInstanceId() {
        return this.InstanceId;
    }

    /**
     * Set 实例D
     * @param InstanceId 实例D
     */
    public void setInstanceId(String InstanceId) {
        this.InstanceId = InstanceId;
    }

    /**
     * Get 目标数据库版本 
     * @return DstMysqlVersion 目标数据库版本
     */
    public String getDstMysqlVersion() {
        return this.DstMysqlVersion;
    }

    /**
     * Set 目标数据库版本
     * @param DstMysqlVersion 目标数据库版本
     */
    public void setDstMysqlVersion(String DstMysqlVersion) {
        this.DstMysqlVersion = DstMysqlVersion;
    }

    public SubmitInstanceUpgradeCheckJobRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public SubmitInstanceUpgradeCheckJobRequest(SubmitInstanceUpgradeCheckJobRequest source) {
        if (source.InstanceId != null) {
            this.InstanceId = new String(source.InstanceId);
        }
        if (source.DstMysqlVersion != null) {
            this.DstMysqlVersion = new String(source.DstMysqlVersion);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "InstanceId", this.InstanceId);
        this.setParamSimple(map, prefix + "DstMysqlVersion", this.DstMysqlVersion);

    }
}

==> tencentcloud-sdk-java-3.1.1157-sources.jar: com/tencentcloudapi/cdb/v20170320/models/SubmitInstanceUpgradeCheckJobRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cdb.v20170320.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SubmitInstanceUpgradeCheckJobRequest extends AbstractModel {

    /**
    * 实例 ID。
    */
    @SerializedName("InstanceId")
    @Expose
    private String InstanceId;

    /**
    * 目标数据库版本。
    */
    @SerializedName("DstMysqlVersion")
    @Expose
    private String DstMysqlVersion;

    /**
     * Get 实例 ID。 
     * @return InstanceId 实例 ID。
     */
    public String getInstanceId() {
        return this.InstanceId;
    }

    /**
     * Set 实例 ID。
     * @param InstanceId 实例 ID。
     */
    public void setInstanceId(String InstanceId) {
        this.InstanceId = InstanceId;
    }

    /**
     * Get 目标数据库版本。 
     * @return DstMysqlVersion 目标数据库版本。
     */
    public String getDstMysqlVersion() {
        return this.DstMysqlVersion;
    }

    /**
     * Set 目标数据库版本。
     * @param DstMysqlVersion 目标数据库版本。
     */
    public void setDstMysqlVersion(String DstMysqlVersion) {
        this.DstMysqlVersion = DstMysqlVersion;
    }

    public SubmitInstanceUpgradeCheckJobRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public SubmitInstanceUpgradeCheckJobRequest(SubmitInstanceUpgradeCheckJobRequest source) {
        if (source.InstanceId != null) {
            this.InstanceId = new String(source.InstanceId);
        }
        if (source.DstMysqlVersion != null) {
            this.DstMysqlVersion = new String(source.DstMysqlVersion);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "InstanceId", this.InstanceId);
        this.setParamSimple(map, prefix + "DstMysqlVersion", this.DstMysqlVersion);

    }
}
